netapp_ontap.models.aggregate_block_storage_primary API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_block_storage_primary`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateBlockStoragePrimarySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateBlockStoragePrimary object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `checksum_style GET POST`

    The checksum style used by the aggregate.

    Valid choices:

    - block
    - advanced_zoned
    - mixed
  `disk_class GET POST`

    The class of disks being used by the aggregate.

    Valid choices:

    - capacity
    - performance
    - archive
    - solid_state
    - array
    - virtual
    - data_center
    - capacity_flash
  `disk_count GET POST PATCH`

    Number of disks used in the aggregate. This includes parity disks, but excludes disks in the hybrid cache.

    Example: 8

  `disk_type GET`

    The type of disk being used by the aggregate.

    Valid choices:

    - fc
    - lun
    - nl_sas
    - nvme_ssd
    - sas
    - sata
    - scsi
    - ssd
    - ssd_cap
    - vm_disk
  `raid_size GET POST PATCH`

    Option to specify the maximum number of disks that can be included in a RAID group.

    Example: 16

  `raid_type GET POST PATCH`

    RAID type of the aggregate.

    Valid choices:

    - raid_dp
    - raid_tec
    - raid0
    - raid4